Improve this doc

# Error: $resource:badargs
Too Many Arguments

    Expected up to 4 arguments [params, data, success, error], got {0} arguments

## Description

This error occurs when specifying too many arguments to a `$resource` action, such as `get`, `query` or any user-defined custom action. These actions may take up to 4 arguments.

For more information, refer to the `$resource` API reference documentation.